========================
Support and Contribution
========================

OpenMSIStream is an open-source project with a strong focus on deployment in, and adaptation to, a wide variety of laboratory settings. The developers are available to support any community users having trouble fully using the software for its intended purposes, and would love to benefit users by adding new functionality, whether that be from users' requests or their own contributions.

Getting Support
---------------

Users encountering any trouble using OpenMSIStream can email the development team directly at openmsistream@gmail.com for specific help or clarification on anything explained in these documentation pages. For more substantive discussions that may include suggestions on changes to OpenMSIStream as it exists, users are encouraged to create new Issues on `the GitHub repository <https://github.com/openmsi/openmsistream/issues/new>`_.

Reporting Issues or Problems
----------------------------

Users should report issues or problems encountered with OpenMSIStream by creating new Issues on `the GitHub repository <https://github.com/openmsi/openmsistream/issues/new>`_.

Contributing to OpenMSIStream
-----------------------------

Users can contribute to OpenMSIStream by forking or cloning `the GitHub repository <https://github.com/openmsi/openmsistream>`_ and `creating Pull Requests <https://github.com/openmsi/openmsistream/compare>`_ from their own forks or branches. Interested users should read :doc:`the page on CI tests <../dev_info/ci_testing>` to learn more about the current existing automatic tests, which include linting using `Pylint <https://pylint.pycqa.org/en/latest/>`_ to enforce a (generally permissive) coding style.
